#
# spec file for package python-xmltodict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-xmltodict
Version:        0.14.2
Release:        1.4
Summary:        Module to make XML working resemble JSON
License:        MIT
URL:            https://github.com/martinblech/xmltodict
Source:         https://files.pythonhosted.org/packages/source/x/xmltodict/xmltodict-%{version}.tar.gz
Patch0:         skip-tests-expat-245.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-xml
BuildArch:      noarch
%python_subpackages

%description
xmltodict is a Python module that makes working with XML feel like you are
working with json, as in this:
http://www.xml.com/pub/a/2006/05/31/converting-between-xml-and-json.html

%prep
%autosetup -p1 -n xmltodict-%{version}
sed -i '1{\@^#!%{_bindir}/env python@d}' xmltodict.py

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/xmltodict.py*
%pycache_only %{python_sitelib}/__pycache__/xmltodict.*.py*
%{python_sitelib}/xmltodict-%{version}*-info

%changelog
* Tue Oct 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.14.2
  * Revert "Ensure significant whitespace is not trimmed"
    This changed was backwards incompatible and caused downstream
    issues.
- Update to version 0.14.1
  * Drop support for Python older than 3.6
  * Additional ruff/Pyflakes/codespell fixes.
- Update to version 0.14.0
  * Drop old Python 2 support leftover code and apply several RUFF
    code health fixes.
  * Add Python 3.11, 3.12 and 3.13 support and tests.
  * Remove defusedexpat import.
  * Replace deprecated BadZipfile with BadZipFile.
  * Support indent using integer format,
    enable python -m unittest tests/*.py.
  * Ensure significant whitespace is not trimmed
  * added conda installation command
  * fix attributes not appearing in streaming mode
* Mon Feb 12 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Sun Jun 19 2022 Dirk Müller <dmueller@suse.com>
- update to 0.13.0:
  * Add install info to readme for openSUSE. (#205)
  * Support defaultdict for namespace mapping (#211)
  * parse(generator) is now possible (#212)
  * Processing comments on parsing from xml to dict (connected to #109) (#221)
  * Add expand_iter kw to unparse to expand iterables (#213)
  * Fixed some typos
  * Add support for python3.8
  * Drop Jython/Python 2 and add Python 3.9/3.10.
  * Drop OrderedDict in Python >= 3.7
  * Do not use len() to determine if a sequence is empty
  * Add more namespace attribute tests
  * Fix encoding issue in setup.py
* Tue Feb 22 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch skip-tests-expat-245.patch:
  * Do not run tests that make no sense with a current Expat.
* Fri May 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Replace nose with pytest
* Sat Apr  6 2019 John Vandenberg <jayvdb@gmail.com>
- Add export LANG=en_US.UTF-8 to fix Leap builds
* Tue Mar 26 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 0.12.0
  * Allow force_commits=True for getting all keys as lists (#204)
  * README.md: fix useless uses of cat (#200)
  * Add FreeBSD install instructions (#199)
  * Fix and simplify travis config (#192)
  * Add support for Python 3.7 (#189)
  * Drop support for EOL Python (#191)
  * Use Markdown long_description on PyPI (#190)
  * correct spelling mistake (#165)
  * correctly unparse booleans (#180)
  * Updates README.md with svg badge
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL.
- Update to version 0.11.0
  * Determine fileness by checking for read attr
  * Add support for Python 3.6.
  * Release as a universal wheel.
  * Updated docs examples to use print function.
  * unparse: pass short_empty_elements to XMLGenerator
  * Added namespace support when unparsing.
* Tue Sep  6 2016 mardnh@gmx.de
- update to version 0.10.2
  + Fixed defusedexpat expat import.
- v0.10.1
  + Use defusedexpat if available.
  + Allow non-string attributes in unparse.
  + Add postprocessor support for attributes.
  + Make command line interface Python 3-compatible.
- v0.10.0
  + Add force_list feature.
  + Add support for Python 3.4 and 3.5.
  + Performance optimization: use list instead of string for CDATA.
  + Include Arch Linux package instructions in README.
  + Improved documentation.
  + Allow any iterable in unparse, not just lists.
  + Bugfix: Process namespaces in attributes too.
  + Better testing under Python 2.6.
- v0.9.2
  + Fix multiroot check for list values
- v0.9.1
  + Only check single root when full_document=True
* Thu Nov 27 2014 boris@steki.net
- add python-xml to all *suse distributions as SLE 12 requires it too
* Mon Nov  3 2014 boris@steki.net
- add python-xml to requires to enable SLE build
* Wed Sep 10 2014 boris@steki.net
- initial packaging of 0.9.0 version
